@@ -3,7 +3,7 @@ Created on 2012-07-16
 
 @author: michael
 '''
-from django.conf.urls.defaults import patterns
+from django.conf.urls import patterns
 
 urlpatterns = patterns('ngrams.views',
     (r'^$','index'),
